#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 old-locale
version:              1.0.0.7
visibility:           public
id:                   old-locale-1.0.0.7-L6Wsx5CTYHFJNpULKIS1yv
key:                  old-locale-1.0.0.7-L6Wsx5CTYHFJNpULKIS1yv
license:              BSD-3-Clause
maintainer:           libraries@haskell.org
synopsis:             locale library
description:
    This package provides the ability to adapt to
    locale conventions such as date and time formats.

category:             System
abi:                  4e6c4002a99b8c58da91871b1948a7f7
exposed:              True
exposed-modules:      System.Locale
import-dirs:          /usr/lib/ghc-8.10.5/site-local/old-locale-1.0.0.7
library-dirs:         /usr/lib/ghc-8.10.5/site-local/old-locale-1.0.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/old-locale-1.0.0.7
hs-libraries:         HSold-locale-1.0.0.7-L6Wsx5CTYHFJNpULKIS1yv
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-old-locale/html/old-locale.haddock
haddock-html:         /usr/share/doc/haskell-old-locale/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

